==> gm-1.6.3_Linux.tar.gz: gm-1.6.3_Linux/libgm/_gm_stbar.c <==
/******************************************************************-*-c-*-
 * Myricom GM networking software and documentation			 *
 * Copyright (c) 2000 by Myricom, Inc.					 *
 * All rights reserved.	 See the file `COPYING' for copyright notice.	 *
 *************************************************************************/

/* author: glenn@myri.com */

#include "gm_debug.h"
#include "gm_internal.h"

/* A nop instruction to trick the caller into flushing all memory writes. */

GM_ENTRY_POINT void
__gm_stbar (void)
{
#if (GM_CPU_sparc || GM_CPU_sparc64) \
&& defined (__SUNPRO_C) || defined (__SUNPRO_CC)
  /* The Sun Forte C/C++ compiler disables optimization for all functions
     that include asm() statements and issues a warning for these functions.
     So, we encapsulate these asms in a wrapper function to minimize the
     number of warnings and allow more optimization, which should negate
     the function call overhead, especially on Sparcs. */
#if defined __sparcv9
  asm ("membar #MemIssue");
#elif defined __sparcv8
  asm ("stbar");
#else
#error Do not know how to implement store barrier.
#endif
  
#elif GM_CPU_x86 && defined _MSC_VER
  /* Don't do anything special here.  The function call forces the compiler
     to do all memory accesses in program order, and the coherence of the
     x86 ensures ordering to the device. */
  return;
#else
  GM_NOTE_ONCE ((__GM_FUNCTION__
		 "() called on an architecture that does not need it."));
#endif
  
}

/*
  This file uses GM standard indentation:

  Local Variables:
  c-file-style:"gnu"
  tab-width:8
  c-backslash-column:72
  End:
*/

==> gm-2.0.8_Linux.tar.gz: gm-2.0.8_Linux/libgm/_gm_stbar.c <==
/******************************************************************-*-c-*-
 * Myricom GM networking software and documentation			 *
 * Copyright (c) 2000 by Myricom, Inc.					 *
 * All rights reserved.	 See the file `COPYING' for copyright notice.	 *
 *************************************************************************/

/* author: glenn@myri.com */

#include "gm_debug.h"
#include "gm_internal.h"

/* A nop instruction to trick the caller into flushing all memory writes. */

GM_ENTRY_POINT void
__gm_stbar (void)
{
#if (GM_CPU_sparc || GM_CPU_sparc64) \
&& defined (__SUNPRO_C) || defined (__SUNPRO_CC)
  /* The Sun Forte C/C++ compiler disables optimization for all functions
     that include asm() statements and issues a warning for these functions.
     So, we encapsulate these asms in a wrapper function to minimize the
     number of warnings and allow more optimization, which should negate
     the function call overhead, especially on Sparcs. */
#if defined __sparcv9
  asm ("membar #MemIssue");
#elif defined __sparcv8
  asm ("stbar");
#else
#error Do not know how to implement store barrier.
#endif
  
#elif (GM_CPU_x86 || GM_CPU_x86_64) && defined _MSC_VER
  /* Don't do anything special here.  The function call forces the compiler
     to do all memory accesses in program order, and the coherence of the
     x86 ensures ordering to the device. */
  return;
#else
  GM_NOTE_ONCE ((__GM_FUNCTION__
		 "() called on an architecture that does not need it."));
#endif
  
}

/*
  This file uses GM standard indentation:

  Local Variables:
  c-file-style:"gnu"
  tab-width:8
  c-backslash-column:72
  End:
*/
